pub struct NormalizedVerifiedCapability {
pub capability: NormalizedCapability,
pub evaluated_at: u64,
}Expand description
Proof-facing verified-capability output.
Fields
capability: NormalizedCapabilityevaluated_at: u64Trait Implementations
Sourceimpl Clone for NormalizedVerifiedCapability
impl Clone for NormalizedVerifiedCapability
Sourcefn clone(&self) -> NormalizedVerifiedCapability
fn clone(&self) -> NormalizedVerifiedCapability
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NormalizedVerifiedCapability
impl Debug for NormalizedVerifiedCapability
Sourceimpl<'de> Deserialize<'de> for NormalizedVerifiedCapability
impl<'de> Deserialize<'de> for NormalizedVerifiedCapability
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for NormalizedVerifiedCapability
impl PartialEq for NormalizedVerifiedCapability
Sourcefn eq(&self, other: &NormalizedVerifiedCapability) -> bool
fn eq(&self, other: &NormalizedVerifiedCapability) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl TryFrom<&VerifiedCapability> for NormalizedVerifiedCapability
impl TryFrom<&VerifiedCapability> for NormalizedVerifiedCapability
Sourcetype Error = NormalizationError
type Error = NormalizationError
The type returned in the event of a conversion error.
impl Eq for NormalizedVerifiedCapability
impl StructuralPartialEq for NormalizedVerifiedCapability